.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    mer 25 dic 2013 14:06:23 CET
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

===================================================
 :mod:`sol.i18n` -- Internationalization utilities
===================================================

.. automodule:: sol.i18n
   :members:
